/*
 * System Interface Library for games
 * Copyright (c) 2007-2017 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/windows/mutex.c: Mutex routines for Windows.
 */

#define IN_SYSDEP

#include "src/base.h"
#include "src/math.h"
#include "src/sysdep.h"
#include "src/sysdep/windows/internal.h"

/*************************************************************************/
/************************** Interface routines ***************************/
/*************************************************************************/

SysMutexID sys_mutex_create(int initially_locked)
{
    HANDLE mutex = CreateMutex(NULL, (initially_locked != 0), NULL);
    if (mutex) {
        return (SysMutexID)mutex;
    } else {
        DLOG("Failed to create mutex");
        return 0;
    }
}

/*-----------------------------------------------------------------------*/

void sys_mutex_destroy(SysMutexID mutex)
{
    CloseHandle((HANDLE)mutex);
}

/*-----------------------------------------------------------------------*/

void sys_mutex_lock(SysMutexID mutex)
{
    WaitForSingleObject((HANDLE)mutex, INFINITE);
}

/*-----------------------------------------------------------------------*/

int sys_mutex_lock_timeout(SysMutexID mutex, float timeout)
{
    return WaitForSingleObject((HANDLE)mutex, iceilf(timeout*1000))
        == WAIT_OBJECT_0;
}

/*-----------------------------------------------------------------------*/

void sys_mutex_unlock(SysMutexID mutex)
{
    ReleaseMutex((HANDLE)mutex);
}

/*************************************************************************/
/*************************************************************************/

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
